/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLTableColElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLTableColElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLTableColElement.h"
#include "gdom/PrivateIntGdomHTMLTableColElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLTableColElement::GDOMHTMLTableColElement(PassRefPtr<WebCore::HTMLTableColElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLTableColElement.h"
#include <gdom/GdomHTMLTableColElement.h>
#include <gdom/PrivateGdomHTMLTableColElement.h>
#include <gdom/PrivateIntGdomHTMLTableColElement.h>
#include <gdom/GdomHTMLTableColElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLTableColElement, gdom_html_table_col_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLTableColElementPrivate {
    class WebCore::HTMLTableColElement *item;
};

#define GDOM_HTML_TABLE_COL_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_TABLE_COL_ELEMENT, GdomHTMLTableColElementPrivate))
*/
G_END_DECLS
WebCore::HTMLTableColElement *
gdom_html_table_col_element_get_private(GdomHTMLTableColElement *request)
{
    GDOMHTMLTableColElement *res;
    res = static_cast<GDOMHTMLTableColElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLTableColElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_ALIGN,
    PROP_CH,
    PROP_CH_OFF,
    PROP_SPAN,
    PROP_V_ALIGN,
    PROP_WIDTH,
};


static void gdom_html_table_col_element_finalize(GObject* object)
{
    /*GdomHTMLTableColElement* request = GDOM_HTML_TABLE_COL_ELEMENT(object);*/
    /*GdomHTMLTableColElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_table_col_element_parent_class)->finalize(object);
}

static void gdom_html_table_col_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLTableColElement *self = GDOM_HTML_TABLE_COL_ELEMENT(object);
    WebCore::HTMLTableColElement * gself = (gdom_html_table_col_element_get_private(self));
    switch (prop_id) {
     case PROP_ALIGN:
    {
         gself->setAlign(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CH:
    {
         gself->setCh(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CH_OFF:
    {
         gself->setChOff(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_SPAN:
    {
         gself->setSpan((g_value_get_long (value)) );
         break;
    }
     case PROP_V_ALIGN:
    {
         gself->setVAlign(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_WIDTH:
    {
         gself->setWidth(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_table_col_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLTableColElement *self = GDOM_HTML_TABLE_COL_ELEMENT(object);
    WebCore::HTMLTableColElement * gself = (gdom_html_table_col_element_get_private(self));
    switch (prop_id) {
    case PROP_ALIGN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->align()));
         break;
    }
    case PROP_CH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->ch()));
         break;
    }
    case PROP_CH_OFF:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->chOff()));
         break;
    }
    case PROP_SPAN:
    {
         g_value_set_long (value, gself->span());
         break;
    }
    case PROP_V_ALIGN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->vAlign()));
         break;
    }
    case PROP_WIDTH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->width()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_table_col_element_class_init(GdomHTMLTableColElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_table_col_element_finalize;
    g_klass->set_property = gdom_html_table_col_element__set_property_fn;
    g_klass->get_property = gdom_html_table_col_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_ALIGN,
            g_param_spec_string ("align", /* name */
                "html_table_col_element_align", /* short description */
                "read-write  gchar * HTMLTableColElement.align", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CH,
            g_param_spec_string ("ch", /* name */
                "html_table_col_element_ch", /* short description */
                "read-write  gchar * HTMLTableColElement.ch", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CH_OFF,
            g_param_spec_string ("ch_off", /* name */
                "html_table_col_element_ch_off", /* short description */
                "read-write  gchar * HTMLTableColElement.ch_off", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_SPAN,
            g_param_spec_long ("span", /* name */
                "html_table_col_element_span", /* short description */
                "read-write  glong HTMLTableColElement.span", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_V_ALIGN,
            g_param_spec_string ("v_align", /* name */
                "html_table_col_element_v_align", /* short description */
                "read-write  gchar * HTMLTableColElement.v_align", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_WIDTH,
            g_param_spec_string ("width", /* name */
                "html_table_col_element_width", /* short description */
                "read-write  gchar * HTMLTableColElement.width", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLTableColElementPrivate));*/
}

static void gdom_html_table_col_element_init(GdomHTMLTableColElement* request)
{
    /*GdomHTMLTableColElementPrivate* priv = GDOM_HTML_TABLE_COL_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

